linux-next: manual merge of the akpm-current tree with the jc_docs tree

From: Stephen Rothwell
Date: Thu Dec 31 2015 - 05:58:57 EST


Hi Andrew,

Today's linux-next merge of the akpm-current tree got a conflict in:

mm/page_alloc.c

between commit:

9daacf51b428 ("Documentation/kernel-parameters: update KMG units")

from the jc_docs tree and commit:

f0a906868be1 ("mm/page_alloc.c: introduce kernelcore=mirror option")

from the akpm-current tree.

I fixed it up (see below) and can carry the fix as necessary (no action
is required).

--
Cheers,
Stephen Rothwell sfr@xxxxxxxxxxxxxxxx

diff --cc mm/page_alloc.c
index 13cf824f6d23,72218a4adab9..000000000000
--- a/mm/page_alloc.c
+++ b/mm/page_alloc.c
@@@ -5500,7 -5718,37 +5718,37 @@@ static void __init find_zone_movable_pf
}

/*
+ * If kernelcore=mirror is specified, ignore movablecore option
+ */
+ if (mirrored_kernelcore) {
+ bool mem_below_4gb_not_mirrored = false;
+
+ for_each_memblock(memory, r) {
+ if (memblock_is_mirror(r))
+ continue;
+
+ nid = r->nid;
+
+ usable_startpfn = memblock_region_memory_base_pfn(r);
+
+ if (usable_startpfn < 0x100000) {
+ mem_below_4gb_not_mirrored = true;
+ continue;
+ }
+
+ zone_movable_pfn[nid] = zone_movable_pfn[nid] ?
+ min(usable_startpfn, zone_movable_pfn[nid]) :
+ usable_startpfn;
+ }
+
+ if (mem_below_4gb_not_mirrored)
+ pr_warn("This configuration results in unmirrored kernel memory.");
+
+ goto out2;
+ }
+
+ /*
- * If movablecore=nn[KMG] was specified, calculate what size of
+ * If movablecore=nn[KMGTPE] was specified, calculate what size of
* kernelcore that corresponds so that memory usable for
* any allocation type is evenly spread. If both kernelcore
* and movablecore are specified, then the value of kernelcore
--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at http://vger.kernel.org/majordomo-info.html
Please read the FAQ at http://www.tux.org/lkml/